# ximgpdf

[![PyPI - Version](https://img.shields.io/pypi/v/ximgpdf?logo=PyPI&label=PyPI)](https://pypi.org/project/ximgpdf/)
![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?logo=Python&label=Python&&tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fpaqira%2Fximgpdf%2Fmain%2Fpyproject.toml)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/paqira/ximgpdf/ci.yaml?logo=GitHub)
![PyPI - License](https://img.shields.io/pypi/l/ximgpdf)

CLI that extracts images from pdf.

## Installation

```shell
pipx install ximgpdf
```

## Usage

```shell
ximgpdf -o output a.pdf b.pdf
```

## Licence

MIT
